[PATCH] mm, docs: fix comments that mention mem_hotplug_end()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Comments that mention mem_hotplug_end() are confusing as there is no
function called mem_hotplug_end(). Fix them by replacing all the
occurences of mem_hotplug_end() in the comments with mem_hotplug_done().

Signed-off-by: Yun-Ze Li <p76091292@xxxxxxxxxxxxxx>
---
 include/linux/mmzone.h | 4 ++--
 mm/compaction.c        | 2 +-
 mm/vmscan.c            | 2 +-
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/mm/compaction.c b/mm/compaction.c
index 65970107b789..b8c1f60c84b9 100644
--- a/mm/compaction.c
+++ b/mm/compaction.c
@@ -3009,7 +3009,7 @@ void kcompactd_run(int nid)
 
 /*
  * Called by memory hotplug when all memory in a node is offlined. Caller must
- * hold mem_hotplug_begin/end().
+ * hold mem_hotplug_begin/done().
  */
 void kcompactd_stop(int nid)
 {
diff --git a/mm/vmscan.c b/mm/vmscan.c
index c6918fff06e1..bd6aaf85ee7f 100644
--- a/mm/vmscan.c
+++ b/mm/vmscan.c
@@ -4586,7 +4586,7 @@ void kswapd_run(int nid)
 
 /*
  * Called by memory hotplug when all memory in a node is offlined.  Caller must
- * hold mem_hotplug_begin/end().
+ * hold mem_hotplug_begin/done().
  */
 void kswapd_stop(int nid)
 {
diff --git a/include/linux/mmzone.h b/include/linux/mmzone.h
index aab70355d64f..7c7947109986 100644
--- a/include/linux/mmzone.h
+++ b/include/linux/mmzone.h
@@ -591,7 +591,7 @@ struct zone {
 	 * give them a chance of being in the same cacheline.
 	 *
 	 * Write access to present_pages at runtime should be protected by
 	 * mem_hotplug_begin/end(). Any reader who can't tolerant drift of
 	 * present_pages should get_online_mems() to get a stable value.
 	 */
 	atomic_long_t		managed_pages;
@@ -870,7 +870,7 @@ typedef struct pglist_data {
 	unsigned long nr_reclaim_start;	/* nr pages written while throttled
 					 * when throttling started. */
 	struct task_struct *kswapd;	/* Protected by
-					   mem_hotplug_begin/end() */
+					   mem_hotplug_begin/done() */
 	int kswapd_order;
 	enum zone_type kswapd_highest_zoneidx;
 
@@ -591,7 +591,7 @@ struct zone {
 	 *
 	 * Write access to present_pages at runtime should be protected by
-	 * mem_hotplug_begin/end(). Any reader who can't tolerant drift of
+	 * mem_hotplug_begin/done(). Any reader who can't tolerant drift of
 	 * present_pages should get_online_mems() to get a stable value.
 	 */
-- 
2.25.1





[Index of Archives]     [Linux ARM Kernel]     [Linux ARM]     [Linux Omap]     [Fedora ARM]     [IETF Annouce]     [Bugtraq]     [Linux OMAP]     [Linux MIPS]     [eCos]     [Asterisk Internet PBX]     [Linux API]

  Powered by Linux